@@ -1,8 +1,8 @@
 from enum import Enum
 from typing import Optional, Union
-from .util import BaseModel
-from .chain import MessageChain
-from .permission import Permission, PermissionEnum
+from karas.util import BaseModel
+from karas.chain import MessageChain
+from karas.permission import Permission, PermissionEnum
 
 """
 由于api统一发送者为sender，所以需要在事件里对sender进行区分
@@ -37,6 +37,9 @@ class Group(ReceptorBase):
     name: str
     permission: Permission
 
+    def __str__(self) -> str:
+        return f"{self.name}[{self.id}]"
+
 
 class Sender(ReceptorBase):
     type: str = "Sender"
@@ -44,6 +47,9 @@ class Sender(ReceptorBase):
     nickname: str
     remark: str
 
+    def __str__(self) -> str:
+        return f"{self.nickname}[{self.id}]"
+
 
 class Friend(ReceptorBase):
     type: str = "Friend"
@@ -51,6 +57,9 @@ class Friend(ReceptorBase):
     nickname: str
     remark: str
 
+    def __str__(self) -> str:
+        return f"{self.nickname}[{self.id}]"
+
 
 class Stranger(ReceptorBase):
     type: str = "Stranger"
@@ -58,6 +67,9 @@ class Stranger(ReceptorBase):
     nickname: str
     remark: str
 
+    def __str__(self) -> str:
+        return f"{self.nickname}[{self.id}]"
+
 
 class Operator(ReceptorBase):
     """
@@ -76,6 +88,9 @@ class Operator(ReceptorBase):
     lastSpeakTimestamp: int
     muteTimeRemaining: int
 
+    def __str__(self) -> str:
+        return f"{self.memberName}[{self.id}]"
+
 
 class Member(ReceptorBase):
     """
@@ -90,12 +105,15 @@ class Member(ReceptorBase):
     muteTimeRemaining: int
     group: Group
 
+    def __str__(self) -> str:
+        return f"{self.memberName}[{self.id}]"
+
 
 class Subject(ReceptorBase):
     """"""
     type: str = "Subject"
     id: int
-    kind: Union["Group", "Friend"]
+    kind: str
 
 
 class Client(ReceptorBase):
