@@ -1,11 +1,11 @@
 from enum import Enum
 from typing import Optional, Union
 
-from .util import BaseModel
+from karas.util import BaseModel
 
-from .Sender import Client, Friend, Group, Member, Operator, Subject
-from .messages import MessageBase, MessageEnum
-from .permission import Permission
+from karas.Sender import Client, Friend, Group, Member, Operator, Subject
+from karas.messages import MessageBase, MessageEnum
+from karas.permission import Permission
 
 __events__ = {
     "messageEvent":
@@ -26,7 +26,7 @@ class EventBase(BaseModel):
     fromId: int = 0
 
     def __str__(self) -> str:
-        return f"{self.__dict__}"
+        return f"{self.type}"
 
 
 class Event(EventBase):
@@ -37,8 +37,6 @@ class Event(EventBase):
         self.event = event
         self.type = kwargs.get("type") or event.type
 
-    def __str__(self) -> str:
-        return f"Event => {self.type}"
 
     def __call__(self, *args, **kwargs):
         pass
@@ -48,15 +46,24 @@ class BotEventBase(EventBase):
     """Bot自身事件"""
     qq: int
 
+    def __str__(self) -> str:
+        return f"{self.__class__}: {self.qq}"
+
 
 class FriendEventBase(EventBase):
     """好友事件"""
     friend: Friend
 
+    def __str__(self) -> str:
+        return f"{self.__class__.__name__}: {self.friend.nickname}({self.friend.id})"
+
 
 class GroupEventBase(EventBase):
     """群组事件"""
 
+    def __init__(self, **kws) -> None:
+        super().__init__(**kws)
+
 
 class RequestEvent(EventBase):
     """申请事件"""
@@ -129,6 +136,9 @@ class BotGroupPermissionChangeEvent(GroupEventBase):
     current: Permission
     group: Group
 
+    def __str__(self) -> str:
+        return f"{self.__class__.type}:{self.origin.type}->{self.current.type}"
+
 
 class BotMuteEvent(GroupEventBase):
     """Bot被禁言"""
@@ -136,12 +146,18 @@ class BotMuteEvent(GroupEventBase):
     durationSeconds: int
     operator: Operator
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.operator}"
+
 
 class BotUnmuteEvent(GroupEventBase):
     """Bot被取消禁言"""
     type: str = "BotUnmuteEvent"
     operator: Operator
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.operator}"
+
 
 class BotJoinGroupEvent(GroupEventBase):
     """Bot加入了一个新群"""
@@ -149,18 +165,27 @@ class BotJoinGroupEvent(GroupEventBase):
     group: Group
     invitor: Optional[Member]
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.group}"
+
 
 class BotLeaveEventActive(GroupEventBase):
     """BotLeaveEventActive"""
     type: str = "BotLeaveEventActive"
     group: Group
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.group}"
+
 
 class BotLeaveEventKick(GroupEventBase):
     """Bot被踢出一个群"""
     type: str = "BotLeaveEventKick"
     operator: Optional[Member]
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.group}"
+
 
 class GroupRecallEvent(GroupEventBase):
     """群消息撤回"""
@@ -171,6 +196,9 @@ class GroupRecallEvent(GroupEventBase):
     group: Group
     operator: Operator
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.operator} <- {self.messageId}"
+
 
 class FriendRecallEvent(EventBase):
     """好友消息撤回"""
@@ -178,7 +206,10 @@ class FriendRecallEvent(EventBase):
     authorId: int
     messageId: int
     time: int
-    operator: Operator
+    operator: int
+
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.operator} <- {self.messageId}"
 
 
 class NudgeEvent(EventBase):
@@ -191,21 +222,24 @@ class NudgeEvent(EventBase):
     target: int
 
     def __init__(self, subject: dict, **kwargs) -> None:
-        self.subject = Subject.parse(**subject)
+        self.subject = Subject(**subject)
         super().__init__(**kwargs)
 
     def __str__(self) -> str:
-        return f"[{super().__str__()}] {self.action} <= {self.target}"
+        return f"NudgeEvent => [{self.fromId}]{self.action}[{self.target}]{self.suffix}"
 
 
 class GroupNameChangeEvent(GroupEventBase):
     """某个群名改变"""
     type: str = "GroupNameChangeEvent"
-    origin: bool
-    current: bool
+    origin: str
+    current: str
     group: Group
     operator: Operator
 
+    def __str__(self) -> str:
+        return super().__str__() + f"{self.group}=>origin:{self.origin} -> current{self.current}"
+
 
 class GroupEntranceAnnouncementChangeEvent(GroupEventBase):
     """某群入群公告改变"""
@@ -215,15 +249,21 @@ class GroupEntranceAnnouncementChangeEvent(GroupEventBase):
     group: Group
     operator: Operator
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.group}"
+
 
 class GroupMuteAllEvent(GroupEventBase):
     """全员禁言"""
     type: str = "GroupMuteAllEvent"
-    origin: str
-    current: str
+    origin: bool
+    current: bool
     group: Group
     operator: Operator
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.operator} -> {self.group}"
+
 
 class GroupAllowAnonymousChatEvent(GroupEventBase):
     """匿名聊天"""
@@ -232,6 +272,9 @@ class GroupAllowAnonymousChatEvent(GroupEventBase):
     group: Group
     operator: Operator
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.operator} -> {self.group}"
+
 
 class GroupAllowConfessTalkEvent(GroupEventBase):
     """坦白说"""
@@ -240,6 +283,10 @@ class GroupAllowConfessTalkEvent(GroupEventBase):
     group: Group
     isByBot: bool
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.group}"
+
+
 
 class GroupAllowMemberInviteEvent(GroupEventBase):
     """允许群员邀请好友加群"""
@@ -249,6 +296,10 @@ class GroupAllowMemberInviteEvent(GroupEventBase):
     group: Group
     operator: Operator
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.operator} -> {self.group}"
+
+
 
 class MemberJoinEvent(GroupEventBase):
     """新人入群的事件"""
@@ -256,6 +307,10 @@ class MemberJoinEvent(GroupEventBase):
     member: Member
     invitor: None
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.member}"
+
+
 
 class MemberLeaveEventKick(GroupEventBase):
     """成员被踢出群聊(该成员不是bot)"""
@@ -263,12 +318,19 @@ class MemberLeaveEventKick(GroupEventBase):
     member: Member
     operator: Operator
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.operator} -> {self.member}"
+
+
 
 class MemberLeaveEventQuit(GroupEventBase):
     """成员退出群聊(该成员不是bot)"""
     type: str = "MemberLeaveEventQuit"
     member: Member
 
+    def __str__(self) -> str:
+        return super().__str__() + f"{self.member}"
+
 
 class MemberCardChangeEvent(GroupEventBase):
     """群名片改动"""
@@ -277,6 +339,9 @@ class MemberCardChangeEvent(GroupEventBase):
     current: str
     member: Member
 
+    def __str__(self) -> str:
+        return super().__str__() + f": {self.member}"
+
 
 class MemberSpecialTitleChangeEvent(GroupEventBase):
     """群头衔改动（只有群主有操作限权）"""
@@ -285,6 +350,8 @@ class MemberSpecialTitleChangeEvent(GroupEventBase):
     current: str
     member: Member
 
+    def __str__(self) -> str:
+        return super().__str__() + f": {self.member}"
 
 class MemberPermissionChangeEvent(GroupEventBase):
     """成员权限改变的事件（该成员不是Bot）"""
@@ -293,6 +360,9 @@ class MemberPermissionChangeEvent(GroupEventBase):
     current: Permission
     member: Member
 
+    def __str__(self) -> str:
+        return super().__str__() + f": {self.member}"
+
 
 class MemberMuteEvent(GroupEventBase):
     """群成员被禁言事件（该成员不是Bot）"""
@@ -301,14 +371,30 @@ class MemberMuteEvent(GroupEventBase):
     member: Member
     operator: Operator
 
+    def __str__(self) -> str:
+        return super().__str__() + f": {self.member}"
+
+class MemberUnmuteEvent(GroupEventBase):
+    """群成员被取消禁言事件（该成员不是Bot）"""
+    type: str = "MemberMuteEvent"
+    durationSeconds: int
+    member: Member
+    operator: Operator
+
+    def __str__(self) -> str:
+        return super().__str__() + f": {self.member}"
+
 
 class MemberHonorChangeEvent(GroupEventBase):
-    """"""
+    """群员称号改变"""
     type: str = "MemberHonorChangeEvent"
     member: Member
     action: str
     honor: str
 
+    def __str__(self) -> str:
+        return super().__str__() + f": {self.member}"
+
 
 class NewFriendRequestEvent(RequestEvent):
     """添加好友申请"""
@@ -319,6 +405,9 @@ class NewFriendRequestEvent(RequestEvent):
     def reject_block(self):
         self.operate = 2
         return __dict__
+    
+    def __str__(self) -> str:
+        return super().__str__() +f":{self.nick}[{self.fromId}]"
 
 class MemberJoinRequestEvent(RequestEvent):
     """用户入群申请（Bot需要有管理员权限）"""
@@ -341,12 +430,18 @@ class MemberJoinRequestEvent(RequestEvent):
         self.operate = 4
         return self.__dict__
 
+    def __str__(self) -> str:
+        return super().__str__() + f":{self.groupName}[{self.groupId}]"
+
 class BotInvitedJoinGroupRequestEvent(RequestEvent):
     """Bot被邀请入群申请"""
     type: str = "BotInvitedJoinGroupRequestEvent"
     groupName: str
     command = "resp_botInvitedJoinGroupRequestEvent"
 
+    def __str__(self) -> str:
+        return super().__str__() +f":{self.groupId}"
+
 
 class OtherClientOnlineEvent(EventBase):
     """其他客户端上线"""
@@ -403,6 +498,7 @@ class EventEnum(Enum):
     MemberSpecialTitleChangeEvent: "MemberSpecialTitleChangeEvent" = MemberSpecialTitleChangeEvent
     MemberPermissionChangeEvent: "MemberPermissionChangeEvent" = MemberPermissionChangeEvent
     MemberMuteEvent: "MemberMuteEvent" = MemberMuteEvent
+    MemberUnmuteEvent: "MemberUnmuteEvent" = MemberUnmuteEvent
     MemberHonorChangeEvent: "MemberHonorChangeEvent" = MemberHonorChangeEvent
     NewFriendRequestEvent: "NewFriendRequestEvent" = NewFriendRequestEvent
     MemberJoinRequestEvent: "MemberJoinRequestEvent" = MemberJoinRequestEvent
